Sub BackScatCoef14 (Zf,Zs,E0,Af,rho,x,eta)

'Backscattering coefficient for thin film-substrat,Reuter (1972)
'Input parameters:  Zf   = atomic number of thin film
'                   Zs   = atomic number of substrate
'                   E0   = energy of elctron beam in keV
'                   Af   = atomic weight of thin film
'                   rho  = density of thin film in g/cm^3
'                   x    = thickness of thin film in microns
'Output paramaeter: eta  = backscattering coefficient

     'Backscattering coefficient for usupported thin film
     'Niedrig (1982)
     R=0.033*(Af/(Zf*rho))*E0^1.65
     if x>=R then
	print"Thin film thickness is greater then calculated."
	print"Electron range (microns):";
	print using"##.###";R
	exit sub
     end if
     a=0.024*Zf^2/Af
     k=-0.2137+0.05108*Zf-7.499e-4*Zf^2+5.807e-6*Zf^3-1.800e-8*Zf^4
     a1=(a*(a+k-1))/((a+k)*(a+k+1))
     a2=(1-(1-2*((a+k)/(a+k-1))*(x/R))*(1-(x/R))^(a+k))
     a3=k*(a+k-2)/((a+k)*(a+k-1))
     a4=(1-(1-2*((a+k-1)/(a+k-2))*(x/R))*(1-(x/R))^(a+k-1))
     etaF=a1*a2+a3*a4
     'Hunger and Kuchler (1979) backscattering coefficient for substrat
     K=0.1904-0.2236*log(Zs)+0.1292*(log(Zs))^2-0.01491*(log(Zs))^3
     m=0.1382-0.9211*Zs^(-0.5)
     etaS=K*E0^m
     x=x*1e-4
     sigma=4.5e+5*E0^(-1.65)
     eta=etaS*exp(-sigma*rho*x)+etaF*(1-exp(-sigma*rho*x))

End Sub
