Sub BackScatCoef19 (E0,Zs,Zf,rhof,rhod,Eta)

'Hunger and Rogaschewski (1986) backscattering coefficients for thin film-substrat combination
'Input parameters:  E0   = energy of electron beam in keV
'                   Zs   = atomic number of substrate
'                   Zf   = atomic number of thin film
'                   rhoF = density of thin film in g/cm^3
'                   rhod = mass thickness of thin film in ug/cm^2
'Output parameters: Eta  = backscattering coefficient for thin film-substrat

   'Eta for bulk substrat,Hunger and Kuchler (1979)
   Ks=0.19036-0.2236*log(Zs)+0.1292*(log(Zs))^2-0.01491*(log(Zs))^3
   ms=0.1382-0.9211*Zs^(-0.5)
   etaS=Ks*E0^ms
   'Eta for bulk thin film,Hunger and Kuchler (1979)
   Kf=0.19036-0.2236*log(Zf)+0.1292*(log(Zf))^2-0.01491*(log(Zf))^3
   mf=0.13982-0.9211*Zf^(-0.5)
   etaF=Kf*E0^mf
   a1=(2.153*Zf-14.789)/(3.706*Zf+17.822)
   a2=(-0.1147*Zf+24.591)/(3.706*Zf+17.822)
   t=(0.00682*Zf+0.821)*E0^(1.801-0.00318*Zf)
   s=rhod/t
   x=a1*s+a2*s^2
   tanh=(exp(x)-exp(-x))/(exp(x)+exp(-x))
   Eta=(etaF-etaS)*tanh+EtaS

End Sub

