Sub BackScatCoef21 (E0,Zs,Asu,rhoS,Zf,Af,rhoF,eta,etaS,d)

'Niedrig-Reuter approach for thin film thickness determination
'B.J.Raeymaekers (1987),Analytical Chemistry,1987,59,930-937.
'Input parameters:  E0   = incident beam energy in keV
'		    Zs   = atomic number of substrate
'		    Asu  = atomic weight of substrate
'                   rhoS = density of substrate in g/cm^3
'                   Zf   = atomic number of thin film
'                   Af   = atomic weight of thin film
'                   rhoF = density of thin film in g/cm^3
'                   etaS = backscattering cofficient of substrate
'                   eta  = experimentally backscattering coefficient of thin film-substrate
'Output parameters: d    = thickness of thin film in microns

   s=4.5e+5*E0^-1.65
   R=0.033*(Af/Zf*rhof)*E0^1.65   'electron range
   R=R/100
   R=R*1e-4
   a=0.024*Zf^2/Af
   k=-0.2137+0.05108*Zf-7.499e-4*Zf^2+5.807e-6*Zf^3-1.800e-8*Zf^4
   'Initial estimate of thickness
   x0=(eta/(a+k))*R
   for i=1 to 100
      a1=s*rhos*x0
      b=etas*exp(-a1)
      x=((eta-b)/(a+k))*R
      if abs(x0-x)<=1e-20 then exit for
      x0=x
   next i
   d=x
   d=d*1e+4

End Sub