Sub BSC25 (Z,A,rho,E0,Ec,Dp,eta)

'Calc backscattering coefficient for the spherical particle
'Markowicz and Van Grieken (1984)
'Input parameters:    Z     :  atomic number
'                     A     :  atomic weight
'                     rho   :  density in g/cm^3
'                     E0    :  incident beam energy in keV
'                     Ec    :  critical excitation energy in keV
'                     Dp    :  particle diamater in microns
'Output parameters:   eta   :  backscattering coefficient of the particle

     'Electron penetration range, Whelan's equation
     d=0.033*(A/(rho*Z))*(E0^1.69-Ec^1.69)
     p=9*Z^(-1/2)
     a1=1/(p-1)
     a2=(2/2^p)-1
     a3=1/(p-2)
     a4=(4/2^p)-1
     eta1=2*(a1*a2-a3*a4)
     if (d*0.3)<=Dp then
	 eta=(eta1/d*0.3)*Dp
     else
	 eta=eta1
     end if

End Sub


