Sub Ics25 (E0,Ec,AtNum,Q)

     'Subroutine to calculated the K shell ionization cross-section
     'based on the Bethe equation and Zaluzec parameterization
     'of the Bethe constants, Zaluzec 1984

     'Q=Ak*nZ*bK*(ln(ck*E/Ec)-ln(1-b2)-b2)/(E*Ec)

     'Input parameters:    E0    :   Accelerating voltage in kV
     '                     Ec    :   Critical excitation enrgy in keV
     '                     AtNum :   Atomic number
     'Output parameter:    Q     :   Ionization cross_section in cm^2

     'Definitions
     'E     : 1/2 moc^2*b2
     'b2    : (v/c)^2=beta squared
     'nZ    : No.of electrons in the excited shell K=2,L=8,M=18
     'Ak    : pi*e^4=6.5144 E-20 (keV-cm)^2
     '      : 6.5144 E +04 barns-keV^2
     'bK,cK : Bethe parameters

     'Calculate betaSQ from accelerating voltage

     Z=AtNum
     Ak=6.5144e-20			'pi*e^4
     nK=2				'No. of electrons in K shell
     betaSQ=1-(1/(1+E0/510.976))^2	'beta squared (v/c)^2
     E=255.488*betaSQ			'1/2 mv^2

     'E0>Ec try to calculate cross-section if atomic number is 3<Z<92
     'Calculate constants based on polynominal fits to
     'experimental relativistic data

     bK=0.988-1.883E-2*Z+3.066E-4*Z^2-2.154E-6*Z^3
     cK=0.2821 +0.077*Z-3.807E-3*Z^2+8.262E-5*Z^3-4.748E-7*Z^4
     Q=aK*nK*bK*(log(cK*E/Ec)+(-log(1-betaSQ)-betaSQ))/(E*Ec)

End Sub