Sub Ics26 (E0,Ec,AtNum,Lines$,Q)

     'Subroutine to calculate  L shell cros-sections for a given
     'incident accelerating voltage , and atomic number
     'using the L-shell parameterization of the Bethe constants
     'determined from Scofield's calculations by Zaluzec 1984

     'Q=Ak*nZ*bL*(ln(cL*E/Ec)-ln(1-b2)-b2)/(E*Ec)

     'Input parameters:  E0      :  Accelerating voltage in kV
     '                   Ec      :  Critical excitaion potential in keV
     '                   AtNum   :  Atomic number
     '                   Lines$  :  Line code "L1","L2","L3"
     'Output parameter:  Q       :  Ionization cross-section cm^2 (barns)

     'Definitions
     'E     : 1/2 moc^2*b2
     'b2    : (v/c)^2=beta squared
     'nZ    : No.of electrons in the excited shell K=2,L=8,M=18
     'Ak    : pi*e^4=6.5144 E-20 (keV-cm)^2
     '      : 6.5144 E +04 barns-keV^2
     'bK,cK : Bethe parameters

     Lines$=Ucase$(Lines$)
     Z=AtNum
     aK=6.5144E-20		        'pi*e^4
     nL=8				'No. of electrons in L shell
     betaSQ=1-(1/(1+E0/510.976))^2 	'beta squared (v/c)^2
     E=255.488*betaSQ			'1/2 mv^2

     'E0>Ec try to calculate cross-section if atomic number is 28<Z<92
     'Calculate constants based on polynomical fits to
     'Scofields relativistic calculations

     if Lines$="L1" then            'L1 subshell
	      bL=0.05217+0.0037*Z-1.354E-4*Z^2+2.255E-6*Z^3-1.742E-8*Z^4+_
		 5.072E-11*Z^5
	      cL=15.9-0.1053*Z-1.421E-3*Z^2+1.23E-5*Z^3
     elseif Lines$="L2" then        'L2 subshell
	      bL=0.2776-6.609E-3*Z+8.711E-5*Z^2-3.599E-7*Z^3
	      cL=-11.16+0.8708*Z-1.362E-2*Z^2+6.261E-5*Z^3
     elseif Lines$="L3" then	    'L3 Subshell
	      bL=0.3962-9.284E-4*Z-1.555E-4*Z^2+2.913E-6*Z^3-1.445E-8*Z^4
	      cL=5.167-0.4527*Z+0.02366*Z^2-3.586E-4*Z^3+1.6700E-6*Z^4
     end if
     'Substitute into Bethe equation
     Q=aK*nL*bL*(log(cL*E/Ec)+(-log(1-betaSQ)-betaSQ))/(E*Ec)

End Sub