Sub MDL1 (a,n,t,I,Ratio,conc,Cmin1,Cmin2)

     'Minimum detectability limit (MDL), Ziebold (1967)
     'Input parameters:  a      :   Empirical parameter
     '                   n      :   Number of measurements
     '                   t      :   Measurement time in seconds
     '                   I      :   Pure element intensity
     '                   Ratio  :   Peak/bakcground ratio for pure standard
     '                   conc   :   Concentration (wt.%) of the element in
     '                              the sample
     'Output parameter:  Cmin   :   Minimum detectable concentration in wt.%

     'Polinomical expression for empirical parameter a
     C=conc
     if a=0.8 then   a=25.451-2.428*C+8.169e-2*C^2-1.062e-3*C^3+4.683e-6*C^4
     if a=1.0 then   a=31.218-3.261*C+0.114*C^2-1.510e-3*C^3+6.703e-6*C^4
     if a=3.0 then   a=52.538-4.922*C+0.158*C^2-2.013e-3*C^3+8.692e-6*C^4
     a2=(n*t*I)^0.5
     a3=a/a2
     Cmin1=a3*C
     'Minimum mass fraction represents the smallest concentration of an
     'element that can be measured in the analysis defined by the
     'spatial resolution, Ziebold (1967) -less accurate expression
     Cmin2=(I*Ratio*t)^0.5

End Sub



