Sub PhiRhoZ6 (Z,A,E0,Ec,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Riveros et al (1987,1992)

     'Input parameters:   Z         :     Atomic number
     '                    A         :     Atomic weight
     '                    E0        :     Incident beam energy in keV
     '                    Ec        :     Critical excitation energy in keV
     '                    rhoz      :     Mass thickness in ug/cm^2
     'Output parameter:   PhiRhoZ   :     PhiRhoZ function

     U0=E0/Ec
     'Mean ionization potential, Brizuela and Riveros (1990)
     J=22.4*Z^(-0.172)
     J=J*Z/1000   'in keV

     'Coefficient alpha, Packwood and Brown (1981)
      alpha1=2.14e5*Z^1.16/(A*E0^1.25)
      alpha2=log(1.166*(E0/J))/(E0-Ec)
      alpha=alpha1*alpha2^0.5

     'Coefficient beta, Tirira et al (1987)
     beta=1.1e5*Z^1.5/((E0-Ec)*A)

     'Backscattering coefficient, Love and Scott (1978)
     eta20=(-52.3791+150.48371*Z-1.167373*Z^2+0.00716*Z^3)*1e-4
     eta1=(-1112.8+30.29*Z-0.15498*Z^2)*1e-4
     eta=eta20*(1+eta1*log(E0/20))

     'Coefficient gama, Tirira et al (1987)
     gama=U0*log(U0)/(U0-1)
     gama=(1+eta)*gama

     'Phi(0) function, Tirira and Riveros (1987)
     phi0=eta*U0*log(U0)/(U0-1)
     phi0=1+phi0

     'Phi-Rho-Z function, Packwood and Brown (1981)
     b1=(gama-phi0)/gama
     b2=exp(-beta*rhoz)
     b3=exp(-alpha^2*rhoz^2)
     PhiRhoZ=gama*(1-b1*b2)*b3

End Sub
