Sub PhiRhoZ7 (Z,A,E0,Ec,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Armstrong (1982,1984,1988)

     'Input parameters:   Z         :     Atomic number
     '                    A         :     Atomic weight
     '                    E0        :     Incident beam energy in keV
     '                    Ec        :     Critical excitation energy in keV
     '                    rhoz      :     Mass thickness in ug/cm^2
     'Output parameter:   PhiRhoZ   :     PhiRhoZ function

     U0=E0/Ec
     'Mean ionization potential, Berger and Selezer (1964)
     J=(9.76+58.8*Z^(-1.19))/1000   'in keV
     J=J*Z

     'Coefficient alpha, Armstrong
     alpha1=2.97e5*Z^1.05/(A*E0^1.25)
     alpha2=(log(1.166*E0/J))/(E0-Ec)
     alpha=alpha1*alpha2^0.5

     'Coefficient gama, Armstrong
     gama1=5*3.1415927*U0/((U0-1)*log(U0))
     gama2=log(U0)-5+5*UO^(-0.2)
     gama0=gama1*gama2

     'Coefficient beta, Armstrong
     beta=8.5e5*Z^2/(A*E0^2*(gama0-1))

     'Backscattering coefficient, Love and Scott (1978)
     eta20=(-52.3791+150.48371*Z-1.167373*Z^2+0.00716*Z^3)*1e-4
     eta1=(-1112.8+30.29*Z-0.15498*Z^2)*1e-4
     eta=eta20*(1+eta1*log(E0/20))

     'Phi(0) function, Love et al (1978)
     aa=3.43378-(10.7872/U0)+(10.97628/U0^2)-(3.62286/U0^3)
     bb=-0.59299+(21.55329/U0)-(30.55248/U0^2)+(9.59218/U0^3)
     phi0=1+eta/(1+eta)
     phi0=phi0*(aa+bb*log(1+eta))

     'Phi-Rho-Z function, Packwood and Brown (1981)
     q=(gama0-phi0)/gama0
     ee1=exp(-alpha^2*rhoz^2)
     ee2=exp(-beta*rhoz)
     PhiRhoz=gama0*ee1*(1-q*ee2)

End Sub
